# FileName: writeToFile.py
# Name: Danielle Perszyk
# This script reads documents from the local database and creates the csv file.
# This file will actually write all three types of climate_properties to the same file,
# however, I will point out where it can be changed to just write one type to the file,
# and then will just need to be run once for every type of climate property.

import csv
import datetime
from pymongo import MongoClient

client = MongoClient('localhost', 27017)

res = client.counties.command('listCollections')

# vars
wind_speed = 0
temperature = 0
humidity = 0
cloud_cover = 0
pressure = 0


res = [c['name'] for c in res['cursor']['firstBatch']]  # gets all collections in the database
searchDay = datetime.datetime(2015, 1, 1, 0, 0, 0)  # starts at January 1, 2015, hour: 0
addHour = datetime.timedelta(hours=1)
addDay = datetime.timedelta(days=1)

# Open file for writing
# Got some help here: http://stackoverflow.com/questions/6159900/correct-way-to-write-line-to-file-in-python
file = open("C://Users/daniperszyk/Desktop/County_Data/Wi_county_full_output.csv", "w",
            newline="")  # + str(i) + "-" + str(j) + ".csv", "w", newline="")

# Create a csv writer
# Documentation here: https://docs.python.org/2/library/csv.html
lineWriter = csv.writer(file, delimiter=',',
                                quotechar='|', quoting=csv.QUOTE_MINIMAL)

for i in range(0, 365):  # iterate through the days in a year
    for j in range(0, 24):  # iterate through the hours in a day
        # for 1 climate_prop, change the below line to read "id", "day", "hour", "climate_prop"
        lineWriter.writerow(["id", "day", "hour", "temperature", "humidity", "wind_speed", "cloud_cover", "pressure"])
        for collection in res:
            # print(client.counties[collection]['time'])
            result = client.counties[collection].find_one({"day_of_year": i})

            if j >= len(result['hours']):  # if there are less than 24 hours, we'll just store them as 1 -> length
                break
            if "windSpeed" not in result['hours'][j]:  # if windspeed not reported, we'll say it's zero
                wind_speed = 0
            else:
                wind_speed = result['hours'][j]["windSpeed"]  # else, use the reported windspeed
            if "temperature" not in result['hours'][j]:  # if temp not reported, use zero
                temperature = 0
            else:
                temperature = result['hours'][j]['temperature']  # else, use reported temp
            if "humidity" not in result['hours'][j]:
                humidity = 0
            else:
                humidity = result['hours'][j]['humidity']
            if "cloudCover" not in result['hours'][j]:
                cloud_cover = 0
            else:
                cloud_cover = result['hours'][j]['cloudCover']
            if "pressure" not in result['hours'][j]:
                pressure = 0
            else:
                pressure = result['hours'][j]['pressure']

            # for just 1 climate_prop, use: ... i, j, climate_prop
            lineWriter.writerow([result['county_id'], i, j, temperature, humidity, wind_speed, cloud_cover, pressure])

        searchDay += addHour  # add an hour

    searchDay += addDay  # add a day
    print("%s%% done!" % (float(i) / 365.0 * 100))  # a progress bar
file.close()



